@@ -84,4 +84,16 @@ Shipwright::Script::Delete - Delete a dist
                                   (info, debug, warn, error, or fatal)
  --log-file FILENAME            : specify the log file
  --unreferenced                 : to delete all unreferenced dists except the last one
- --check-only                   : check the lists, not really delete
+ --check-only                   : show the lists, not really delete
+
+=head1 AUTHORS
+
+sunnavy  C<< <sunnavy@bestpractical.com> >>
+
+=head1 LICENCE AND COPYRIGHT
+
+Shipwright is Copyright 2007-2009 Best Practical Solutions, LLC.
+
+This program is free software; you can redistribute it and/or modify it
+under the same terms as Perl itself.
+
