@@ -25,6 +25,11 @@ sub run {
     my $versions = $shipwright->backend->version;
     my $source   = $shipwright->backend->source;
     my $refs     = $shipwright->backend->refs || {};
+    my $branches;
+
+    if ( $shipwright->backend->has_branch_support ) {
+        $branches = $shipwright->backend->branches;
+    }
 
     my $latest_version = {};
 
@@ -35,7 +40,7 @@ sub run {
         my $map = $shipwright->backend->map;
 
         if ($name) {
-            if ( $name =~ /^cpan-/ ) {
+            if ( $name =~ /^cpan-/ && !$source->{$name} ) {
                 my %reversed = reverse %$map;
                 my $module   = $reversed{$name};
                 $latest_version->{$name} =
@@ -56,9 +61,12 @@ sub run {
 
             for my $name ( keys %$source ) {
                 next if exists $latest_version->{$name};
-                if ( $source->{$name} =~ m{^sv[nk]:} ) {
-                    $latest_version->{$name} =
-                      $self->_latest_version( url => $source->{$name} );
+                if ( $source->{$name} =~ m{^(sv[nk]|shipwright):} ) {
+                    for my $branch ( keys %{ $source->{$name} } ) {
+                        $latest_version->{$name}{$branch} =
+                          $self->_latest_version(
+                            url => $source->{$name}{$branch} );
+                    }
                 }
             }
         }
@@ -78,22 +86,74 @@ sub run {
             if ( $latest_version->{$name} ) {
                 require version;
                 my $latest = version->new( $latest_version->{$name} );
-                if ( $latest gt $versions->{$name} ) {
+                if ( ref $versions->{$name} ) {
+
+                  # we show this dist if at least one of the branches has update
+                    for my $branch ( keys %{ $versions->{$name} } ) {
+                        if ( $latest gt $versions->{$name}{$branch} ) {
+                            $flip = 1;
+                            last;
+                        }
+                    }
+                }
+                elsif ( $latest gt $versions->{$name} ) {
                     $flip = 1;
                 }
             }
-
         }
 
         if ($flip) {
             print $name, ': ', "\n";
-            print ' ' x 4 . 'version: ', $versions->{$name} || '',     "\n";
-            print ' ' x 4 . 'from: ',    $source->{$name}   || 'CPAN', "\n";
+            print ' ' x 4 . 'version: ';
+            if ( ref $versions->{$name} ) {
+
+                if ( $name =~ /^cpan-/ ) {
+                    print $versions->{$name}{'vendor'}, "\n";
+                }
+                else {
+                    print "\n";
+                    for my $branch ( keys %{ $versions->{$name} } ) {
+                        print ' ' x 8, $branch, ': ',
+                          $versions->{$name}{$branch} || '', "\n";
+                    }
+                }
+            }
+            else {
+                print $versions->{$name} || '', "\n";
+            }
+
+            print ' ' x 4 . 'from: ';
+            if ( ref $source->{$name} ) {
+                print "\n";
+                for my $branch ( keys %{ $source->{$name} } ) {
+                    print ' ' x 8, $branch, ': ',
+                      $source->{$name}{$branch} || '', "\n";
+                }
+            }
+            else {
+                print $source->{$name} || 'CPAN', "\n",;
+            }
+
             print ' ' x 4 . 'references: ',
               defined $refs->{$name} ? $refs->{$name} : 'unknown', "\n";
+
             if ( $self->with_latest_version ) {
-                print ' ' x 4 . 'latest_version: ', $latest_version->{$name}
-                  || 'unknown', "\n";
+                print ' ' x 4, 'latest_version: ';
+                if ( ref $source->{$name} ) {
+                    print "\n";
+                    for my $branch ( keys %{ $source->{$name} } ) {
+                        print ' ' x 8, $branch, ': ',
+                          $latest_version->{$name}{$branch} || 'unknown', "\n";
+                    }
+                }
+                else {
+                    print $latest_version->{$name} || 'unknown', "\n";
+                }
+            }
+
+            if ($branches && $name !~ /^cpan-/) {
+                print ' ' x 4 . 'branches: ',
+                  join( ', ', @{ $branches->{$name} } ), "\n";
             }
         }
     }
@@ -110,14 +170,20 @@ sub _latest_version {
 
         my ( $cmd, $out );
 
+        # XXX TODO we need a better latest_version for shipwright source
+        # using the source shipwright repo's whole version seems lame
+        if ( $args{url} =~ s/^shipwright:// ) {
+            $args{url} =~ s!/[^/]+$!!;
+        }
+
         # has url, meaning svn or svk
         if ( $args{url} =~ /^svn[:+]/ ) {
             $args{url} =~ s{^svn:(?!//)}{};
-            $cmd = [ 'svn', 'info', $args{url} ];
+            $cmd = [ $ENV{'SHIPWRIGHT_SVN'}, 'info', $args{url} ];
         }
         elsif ( $args{url} =~ m{^(svk:|//)} ) {
             $args{url} =~ s/^svk://;
-            $cmd = [ 'svk', 'info', $args{url} ];
+            $cmd = [ $ENV{'SHIPWRIGHT_SVK'}, 'info', $args{url} ];
         }
 
         ($out) = Shipwright::Util->run( $cmd, 1 );    # ignore failure
@@ -164,3 +230,15 @@ Shipwright::Script::List - List dists of a project
                                      (info, debug, warn, error, or fatal)
    --with-latest-version           : show the latest version if possible
    --only-update                   : only show the dists that can be updated
+
+=head1 AUTHORS
+
+sunnavy  C<< <sunnavy@bestpractical.com> >>
+
+=head1 LICENCE AND COPYRIGHT
+
+Shipwright is Copyright 2007-2009 Best Practical Solutions, LLC.
+
+This program is free software; you can redistribute it and/or modify it
+under the same terms as Perl itself.
+
