@@ -27,8 +27,8 @@ sub run {
     confess "no such dist: $name\n" unless grep { $_ eq $name } @$order;
 
     $shipwright->backend->move(
-        path     => "/dists/$name",
-        new_path => "/dists/$new_name",
+        path     => "/sources/$name",
+        new_path => "/sources/$new_name",
     );
     $shipwright->backend->move(
         path     => "/scripts/$name",
@@ -46,13 +46,14 @@ sub run {
     }
     $shipwright->backend->map($map);
 
-    # update version.yml, source.yml and flags.yml
-    my $version = $shipwright->backend->version || {};
-    my $source  = $shipwright->backend->source  || {};
-    my $flags   = $shipwright->backend->flags   || {};
-    my $refs    = $shipwright->backend->refs    || {};
+    my $version = $shipwright->backend->version;
+    my $source  = $shipwright->backend->source;
+    my $flags   = $shipwright->backend->flags;
+    my $refs    = $shipwright->backend->refs;
+    my $branches= $shipwright->backend->branches;
 
-    for my $hashref ( $source, $flags, $version, $refs ) {
+    for my $hashref ( $source, $flags, $version, $refs, $branches ) {
+        next unless $hashref; # branches can be undef
         for ( keys %$hashref ) {
             if ( $_ eq $name ) {
                 $hashref->{$new_name} = delete $hashref->{$_};
@@ -65,6 +66,7 @@ sub run {
     $shipwright->backend->source($source);
     $shipwright->backend->flags($flags);
     $shipwright->backend->refs($refs);
+    $shipwright->backend->branches($branches) if $branches;
 
     print "renamed $name to $new_name with success\n";
 }
@@ -87,3 +89,15 @@ Shipwright::Script::Rename - Rename a dist
  -l [--log-level] LOGLEVEL    : specify the log level
                                 (info, debug, warn, error, or fatal)
  --log-file FILENAME          : specify the log file
+
+=head1 AUTHORS
+
+sunnavy  C<< <sunnavy@bestpractical.com> >>
+
+=head1 LICENCE AND COPYRIGHT
+
+Shipwright is Copyright 2007-2009 Best Practical Solutions, LLC.
+
+This program is free software; you can redistribute it and/or modify it
+under the same terms as Perl itself.
+
