@@ -370,7 +370,13 @@ EOF
                                 _path   => undef,
                             );
                         }
-                        $s->run();
+                        unless ($s->run()) { 
+                            # if run returns false, we should skip trying to install it.
+                            # this lets us skip explicit dependencies that are actually part of the perl core
+                            #delete $require->{$type}{$module};
+                            next;
+
+                        }
                         chdir $cwd;
                     }
 
